#
# spec file for package gvisor-tap-vsock
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gvisor-tap-vsock
Version:        0.8.5
Release:        1.1
Summary:        Go replacement for libslirp and VPNKit
License:        Apache-2.0
Group:          Systems/Networking
URL:            https://github.com/containers/%{name}
Source0:        gvisor-tap-vsock-%{version}.tar.xz
BuildRequires:  gcc
BuildRequires:  golang >= 1.16.6
BuildRequires:  golang-packaging
BuildRequires:  systemd-rpm-macros
Provides:       gvproxy = %{version}-%{release}

%description
%{summary}

%{name} is based on the network stack of gVisor. Compared to libslirp,
%{name} brings a configurable DNS server and
dynamic port forwarding.

%prep
%autosetup -a0

%build
go build \
    -buildmode pie \
    -ldflags "-linkmode=external -s -w" \
    -o bin/gvproxy ./cmd/gvproxy

go build \
    -buildmode pie \
    -ldflags "-linkmode=external -s -w" \
    -o bin/gvforwarder ./cmd/vm

%install
install -D -m 0755 bin/gvproxy %{buildroot}%{_libexecdir}/podman/gvproxy
install -D -m 0755 bin/gvforwarder %{buildroot}%{_libexecdir}/podman/gvforwarder
install -D -m0644 contrib/systemd/gv-user-network@.service -t %{buildroot}%{_unitdir}

%pre
%service_add_pre gv-user-network@.service

%post
%service_add_post gv-user-network@.service

%preun
%service_del_preun gv-user-network@.service

%postun
%service_del_postun gv-user-network@.service

%files
%dir %{_libexecdir}/podman
%{_libexecdir}/podman/gvproxy
%{_libexecdir}/podman/gvforwarder
%{_unitdir}/gv-user-network@.service

%changelog
* Fri Mar 21 2025 madhankumar.chellamuthu@suse.com
- Update to version 0.8.5:
  * build(deps): bump golang.org/x/net from 0.33.0 to 0.36.0
  * build(deps): bump golang.org/x/mod from 0.22.0 to 0.24.0
  * build(deps): bump golang.org/x/crypto from 0.32.0 to 0.36.0
  * Fix lit error
  * Upgrade to go '1.23.0'
  * fix vfkit socket disposal
  * Trim 'search' list field on macOS
  * Remove filewatcher package
  * build: Run go mod tidy
  * gvproxy: command: Add AddServiceEndpoint
  * Delete unused files and dependencies.
  * Revert "Replace multiple "resolver.*" fn cals with single "dns.Exchange()" fn."
  * OWNERS: Add Yevhen and Luca as approvers
  * Add make target to enable debugger during test run
  * build(deps): bump github.com/miekg/dns from 1.1.62 to 1.1.63
  * test: upload and download tests against vfkit
  * Use poll based file watcher
  * doc: update doc with new services option
  * Add --services flag to start API without using --listen flag
  * Revert "Update ubuntu runner to 'ubuntu-24.04'"
  * Watch /etc/resolv.conf changes
  * Migrate HostFile to use the common filewatcher utility
  * Extract out filewatcher functionality
  * add back the generic test command and use it on gh workflow
  * add build tag to vfkit test files
  * Allow empty list of nameservers
  * test: Add a test to check an already exposed port cannot be exposed again
  * forwarder: Use distinct type for `proxies` map key
  * Fix `PortsForwarder.Expose()` proxy check
  * Update ubuntu runner to 'ubuntu-24.04'
  * test: add basic tests for vfkit
  * test: move test utils files to the test-utils folder
  * Warn user and keep executing if Event Log Service is stopped
  * build(deps): bump golang.org/x/crypto from 0.31.0 to 0.32.0
  * build(deps): bump github.com/onsi/gomega from 1.36.0 to 1.36.2
  * ghactions: Run `apt update` before installing packages
  * build(deps): bump golang.org/x/sys from 0.28.0 to 0.29.0
  * Fix error "-forward-sock" -> "--forward-sock"
  * build(deps): bump golang.org/x/crypto from 0.29.0 to 0.31.0
* Mon Dec 16 2024 madhankumar.chellamuthu@suse.com
- Update to version 0.8.1:
  * build(deps): bump github.com/onsi/gomega from 1.35.1 to 1.36.0
  * win-sshproxy.tid created before thread id is available
  * build(deps): bump github.com/stretchr/testify from 1.9.0 to 1.10.0
  * Avoid crash with empty resolv.conf
  * Use all configured ipv4 dns services
  * build(deps): bump golang.org/x/crypto from 0.28.0 to 0.29.0
  * build(deps): bump github.com/coreos/stream-metadata-go
  * build(deps): bump github.com/fsnotify/fsnotify from 1.7.0 to 1.8.0
  * build(deps): bump github.com/onsi/gomega from 1.34.2 to 1.35.1
  * Update to gvisor release-20240916.0
  * tcpproxy: remove unused functions
  * tcpproxy: add `nolint:errcheck`
  * go.mod: remove `replace inet.af/tcpproxy => github.com/inetaf/tcpproxy`
  * Move several log messages to the debug level
  * build(deps): bump github.com/fsnotify/fsnotify from 1.4.9 to 1.7.0
  * build(deps): bump golang.org/x/crypto from 0.27.0 to 0.28.0
  * Disable ssh port forwarding when value of -ssh-port is -1
  * Check 'hosts' file records, during handling DNS requests
  * Update to gvisor release-20240826.0
  * Bump gvisor.dev/gvisor to 20240729.0
  * gha: Update go versions
  * packit: Don't attempt to build on f39
  * build(deps): bump github.com/onsi/gomega from 1.34.1 to 1.34.2
  * Fix consistent udp packet loss after the proxy read loop stopped
  * OWNERS: Add Yevhen to 'reviewers'
  * dns: Fix UDP and TCP request handling
  * Replace multiple "resolver.*" fn cals with single "dns.Exchange()" fn.
  * build(deps): bump golang.org/x/crypto from 0.26.0 to 0.27.0
  * Add dependency on "github.com/qdm12/dns/v2"
  * Add 'addLocalAnswers' helper
  * Add DNS server test
  * Add "IdentitiesOnly" SSH option to fix running tests when known_hosts has multiple records
  * build(deps): bump github.com/vishvananda/netlink from 1.2.1 to 1.3.0
  * build(deps): bump github.com/vishvananda/netlink
  * test: Use crc.dev records for DNS tests
  * lint: Fix non-constant format string error
  * deps: Update golangci-lint to v1.60.1
  * gha: Use 'make lint' instead of golangci-lint-action
  * deps: Revert inetaf/tcpproxy commit 2862066
  * build(deps): bump golang.org/x/crypto from 0.25.0 to 0.26.0
  * build(deps): bump github.com/miekg/dns from 1.1.61 to 1.1.62
  * build(deps): bump golang.org/x/sys from 0.22.0 to 0.24.0
  * build(deps): bump github.com/onsi/gomega from 1.33.1 to 1.34.1
  * ghactions: Automatically create gh releases
* Mon Jul 29 2024 danish.prakash@suse.com
- Update to version 0.7.4:
  * build(deps): bump golang.org/x/crypto from 0.24.0 to 0.25.0
  * go.mod: Update go to 1.21
  * go.mod: Update github.com/insomniacslk/dhcp to latest git main
  * Fix OS specific url handling for unix:// scheme in transport
  * test: fix broken dns TXT lookup test
  * handle ENOBUFS when writing to VM socket
  * build(deps): bump github.com/miekg/dns from 1.1.59 to 1.1.61
  * build(deps): bump golang.org/x/sys from 0.20.0 to 0.21.0
  * test: Specify path to EFI firmware for aarch64
  * test: Use 'virt' machine type on aarch64
  * test: Pick correct qemu-system-$arch binary
  * test: Make getFCOSDownload less arch-dependent
  * test: Fix expected wikipedia.org TXT record
  * build(deps): bump golang.org/x/crypto from 0.22.0 to 0.23.0
  * Packit: remove EL8 and enable C10S downstream update
  * ghactions: Use ubuntu runner for tests
  * ghactions: setup-go: Use go version from go.mod
  * test: Always set QEMU machine type and accel
  * test: Rework qemuExecutable
  * ghactions: Don't use pre-release golang 1.22
  * build(deps): bump github.com/onsi/gomega from 1.32.0 to 1.33.1
  * build(deps): bump github.com/miekg/dns from 1.1.58 to 1.1.59
  * build(deps): bump golangci/golangci-lint-action from 4 to 6
  * build(deps): bump github.com/Microsoft/go-winio from 0.6.1 to 0.6.2
  * build(deps): bump golang.org/x/net from 0.21.0 to 0.23.0
  * README: Clarify that the host HTTP API is not always there
  * build(deps): bump golang.org/x/sync from 0.6.0 to 0.7.0
  * build(deps): bump golang.org/x/crypto from 0.21.0 to 0.22.0
  * build: Build arm64 Windows binaries
  * go.mod: Change inet.af/tcpproxy to github.com/inetaf/tcpproxy
  * build(deps): bump github.com/onsi/gomega from 1.31.1 to 1.32.0
  * build(deps): bump google.golang.org/protobuf in /tools
  * build(deps): bump golang.org/x/crypto from 0.19.0 to 0.21.0
  * build(deps): bump github.com/stretchr/testify from 1.8.4 to 1.9.0
  * build(deps): bump golang.org/x/sys from 0.17.0 to 0.18.0
  * build(deps): bump golangci/golangci-lint-action from 3 to 4
  * Add DNS '8.8.8.8' server to use in test
  * Fix lint errors
  * build(deps): bump golang.org/x/crypto from 0.18.0 to 0.19.0
  * OWNERS: Add jakecorrenti to reviewers
  * gh: Fix 'if:' statement to avoid multiple uploads
  * build(deps): bump actions/setup-go from 3 to 5
  * build(deps): bump actions/checkout from 3 to 4
  * build(deps): bump actions/upload-artifact from 3 to 4
  * build(deps): bump github.com/onsi/gomega from 1.30.0 to 1.31.1
  * test: Increase `go test` timeout
  * ghactions: Don't upload artifacts multiple times
  * Add log-file to proxy builder
  * ghactions: Fix version generation for ghactions builds
  * Improve versioning from shallow git clones
  * gvproxy: Add more context to errors
  * build(deps): bump github.com/miekg/dns from 1.1.57 to 1.1.58
  * ghactions: Build release artifacts on tag push
  * dependabot: Enable automatic github actions updates
* Tue Jan 23 2024 danish.prakash@suse.com
- Update to version 0.7.2:
  * Add --log-file to gvproxy
  * ssh: Recreate connection on retries in setupProxy
  * build(deps): bump golang.org/x/sync from 0.5.0 to 0.6.0
  * build(deps): bump golang.org/x/crypto from 0.17.0 to 0.18.0
  * ghactions: add Go 1.22rc1
  * go.mod: gvisor.dev/gvisor v0.0.0-20231023213702-2691a8f9b1cf
  * ssh: Add when to setupProxy
  * ssh: Introduce 'retry' helper
  * [CI:BUILD] packit: simplify config after F37 EOL
  * version: Add versioning for github tarballs
  * version: Add moduleVersionFromBuildInfo
  * cmd/*: Add -version flag to executables
  * build(deps): bump golang.org/x/crypto from 0.15.0 to 0.17.0
  * build: Use ldflags in win-{gvproxy,sshproxy} targets
  * build(deps): bump github.com/coreos/stream-metadata-go
  * build(deps): bump github.com/miekg/dns from 1.1.56 to 1.1.57
  * build(deps): bump github.com/onsi/gomega from 1.28.0 to 1.30.0
  * build(deps): bump golang.org/x/sync from 0.4.0 to 0.5.0
  * build(deps): bump golang.org/x/crypto from 0.14.0 to 0.15.0
  * lint: Stop using dot imports
  * tools: Update golangci-lint to latest version
  * transport: Support passing CID for linux vsock
  * Packit: enable f39 downstream tasks
  * build(deps): bump golang.org/x/net from 0.15.0 to 0.17.0
  * build(deps): bump golang.org/x/sync from 0.3.0 to 0.4.0
  * build(deps): bump golang.org/x/crypto from 0.13.0 to 0.14.0
  * build(deps): bump github.com/onsi/gomega from 1.27.10 to 1.28.0
  * Packit: add ppc64le and s390x targets for podman-next copr
  * build(deps): bump github.com/miekg/dns from 1.1.55 to 1.1.56
  * Add graceful shutdown support for gvproxy on Win
  * ghactions: Add comment explaining why we stay on ubuntu-20.04
  * ghactions: Use macos-latest instead of macos-11
  * ghactions: Use `make win-sshproxy`
  * ghactions: build: Add win-gvproxy and win-sshproxy
  * Packit: enable f39 targets
  * rpm: correctly obsolete older rpm builds
  * rpm: gvforwarder subpackage
  * Packit: reuse copr targets for podman-next
  * Rename Command type to GvproxyCommand
  * Fixes the generated commandline for the Command type
  * README: More vfkit updates
  * build(deps): bump golang.org/x/crypto from 0.12.0 to 0.13.0
  * build: Add freebsd build to make cross
  * transport: Refactor 'Listen' code
  * transport: Only build unixgram on darwin
  * build: Use golangci-lint from tools/
  * tools: go.mod: Switch to golang 1.20
  * tools: Rename go module
  * build: Remove -arm64/-amd64 darwin binaries after makefat
  * build: Build arm64 linux binary
  * ghactions: Build on ubuntu 20.04
  * Fix golangci-lint errors
  * build(deps): bump golang.org/x/crypto from 0.11.0 to 0.12.0
  * Add `Command` type
  * packit: Build PRs into default packit COPRs
  * build(deps): bump golang.org/x/sys from 0.10.0 to 0.11.0
  * gvproxy: add docker.internal dns entries
  * Packit: switch to rpm/gvisor-tap-vsock.spec
  * README.md: Replace hyperkit with vfkit
  * README.md: Fix QEMU spelling
* Thu Aug  3 2023 danish.prakash@suse.com
- Use .obscpio archive format with obs_scm svc
- Update to version 0.7.0:
  * build(deps): bump github.com/onsi/gomega from 1.27.8 to 1.27.10
  * build(deps): bump golang.org/x/crypto from 0.10.0 to 0.11.0
  * go.mod: gvisor.dev/gvisor v0.0.0-20230715022000-fd277b20b8db
  * go.mod: gvisor.dev/gvisor v0.0.0-20230518002134-99c295d3b367
  * build: Update go version to 1.20
  * Update packit targets
  * build(deps): bump golang.org/x/sys from 0.9.0 to 0.10.0
  * build(deps): bump github.com/coreos/stream-metadata-go
  * Remove unnecessary allocations and Write calls.
* Thu Jul 27 2023 Danish Prakash <danish.prakash@suse.com>
- First version of the gvisor-tap-vsock package
